@@ -2,7 +2,7 @@
 import copy
 import unittest
 
-from mock import patch, Mock
+from mock import patch, Mock, mock_open
 from crunner.config import ConfigLoader
 
 
@@ -40,7 +40,7 @@ class TestHelper(unittest.TestCase):
 
 @patch('crunner.config.log', Mock())
 class TestConfig(TestHelper):
-    @patch('__builtin__.open', Mock())
+    @patch('__builtin__.open', mock_open())
     @patch('crunner.config.json.loads')
     @patch('crunner.config.os.path.exists', Mock(return_value=True))
     def test__load__returns_notify_and_pytest_path_and_projects(self, fake_loads):
@@ -64,14 +64,14 @@ class TestConfig(TestHelper):
     def test__load__exits_if_file_does_not_exist(self, exists_mock):
         self._check_if_exit(False, exists_mock)
 
-    @patch('__builtin__.open', Mock())
+    @patch('__builtin__.open', mock_open())
     @patch('crunner.config.json.loads')
     @patch('crunner.config.os.path.exists', Mock(return_value=True))
     def test__load__exits_if_json_format_is_not_correct(self, fake_loads):
         fake_loads.side_effect = ValueError("Wrong syntax")
         self.assertRaises(SystemExit, ConfigLoader().load)
 
-    @patch('__builtin__.open', Mock())
+    @patch('__builtin__.open', mock_open())
     @patch('crunner.config.json.loads')
     @patch('crunner.config.os.path.exists', Mock(return_value=True))
     def test__load__exits_if_notifier_does_not_exist(self, fake_loads):
@@ -79,7 +79,7 @@ class TestConfig(TestHelper):
         del config['notifier']
         self._check_if_exit(config, fake_loads)
 
-    @patch('__builtin__.open', Mock())
+    @patch('__builtin__.open', mock_open())
     @patch('crunner.config.json.loads')
     @patch('crunner.config.os.path.exists', Mock(return_value=True))
     def test__load__exits_if_notifier_does_not_exist(self, fake_loads):
@@ -87,7 +87,7 @@ class TestConfig(TestHelper):
         del config['tester']
         self._check_if_exit(config, fake_loads)
 
-    @patch('__builtin__.open', Mock())
+    @patch('__builtin__.open', mock_open())
     @patch('crunner.config.json.loads')
     @patch('crunner.config.os.path.exists', Mock(return_value=True))
     def test__load__exits_if_notifier_subkey_does_not_exist(self, fake_loads):
@@ -95,7 +95,7 @@ class TestConfig(TestHelper):
         del config['notifier']['cmd']
         self._check_if_exit(config, fake_loads)
 
-    @patch('__builtin__.open', Mock())
+    @patch('__builtin__.open', mock_open())
     @patch('crunner.config.json.loads')
     @patch('crunner.config.os.path.exists', Mock(return_value=True))
     def test__load__exits_if_tester_subkey_does_not_exist(self, fake_loads):
@@ -103,7 +103,7 @@ class TestConfig(TestHelper):
         del config['tester']['cmd']
         self._check_if_exit(config, fake_loads)
 
-    @patch('__builtin__.open', Mock())
+    @patch('__builtin__.open', mock_open())
     @patch('crunner.config.json.loads')
     @patch('crunner.config.os.path.exists', Mock(return_value=True))
     def test__load__exits_if_project_subkey_does_not_exist(self, fake_loads):
